.control.label.iptables-action {
    border-radius: 3px;
    background: #888;
    color: white;
    padding: 0 5px;
    text-shadow: 0 -1px 0 rgba(0, 0, 0, .5);
    box-shadow: 0 1px 1px #444;
    font-weight: bold;

    &.iptables-ACCEPT {
        background: #62BD00;
    }

    &.iptables-REJECT {
        background: #F51D1D;
    }

    &.iptables-DROP {
        background: #E47620;
    }
}