(function(){var a;a=(function(){function b(){if(window.parent){this.target=window.parent;this.domainPolicy="*";this.enabled=true}}b.prototype.send=function(d,e){var c;if(this.enabled){if(e==null){e={}}c={event:d,data:e};return this.target.postMessage(c,this.domainPolicy)}};b.prototype.reportHeight=function(c){return this.send("height",c)};return b})();$(function(){window.aoConnector=new a();return window.aoConnector.send("ready")})}).call(this);